@@ -1,12 +1,16 @@
 package Net::DNS;
 
 #
-# $Id: DNS.pm 1454 2016-02-05 12:13:15Z willem $
+# $Id: DNS.pm 1460 2016-02-25 09:55:34Z willem $
 #
-use vars qw($VERSION $SVNVERSION);
-$VERSION    = '1.04_03';
-$VERSION    = eval $VERSION;
-$SVNVERSION = (qw$LastChangedRevision: 1454 $)[1];
+BEGIN {
+	require 5.004_04;
+	require vars;
+	'vars'->import(qw($VERSION $SVNVERSION));
+	$VERSION    = '1.04_04';
+	$VERSION    = eval $VERSION;
+	$SVNVERSION = (qw$LastChangedRevision: 1460 $)[1];
+}
 
 
 =head1 NAME
@@ -30,15 +34,15 @@ details.
 =cut
 
 
-use 5.004_04;
 use strict;
 use integer;
 
 use base qw(Exporter);
-use vars qw(@EXPORT);
+use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = qw(SEQUENTIAL UNIXTIME YYYYMMDDxx
 		yxrrset nxrrset yxdomain nxdomain rr_add rr_del
-		mx query rrsort);
+		mx rrsort);
+@EXPORT_OK = qw(query);
 
 
 use Net::DNS::RR;
@@ -264,7 +268,7 @@ Returns the version of Net::DNS.
 =head2 query
 
     # Use a default resolver -- can not get an error string this way.
-    use Net::DNS;
+    use Net::DNS qw(query);
     my @rr = query("example.com");
     my @rr = query("example.com", "A");
     my @rr = query("example.com", "A", "IN");
@@ -287,7 +291,7 @@ See L</EXAMPLES> for more complete examples.
 =head2 mx
 
     # Use a default resolver -- can not get an error string this way.
-    use Net::DNS;
+    use Net::DNS qw(mx);
     my @mx = mx("example.com");
 
     # Use your own resolver object.
