@@ -1,10 +1,10 @@
 package Net::DNS::RR::DNAME;
 
 #
-# $Id: DNAME.pm 1382 2015-08-26 20:39:33Z willem $
+# $Id: DNAME.pm 1456 2016-02-17 13:34:00Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1382 $)[1];
+$VERSION = (qw$LastChangedRevision: 1456 $)[1];
 
 
 use strict;
@@ -32,16 +32,16 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{target};
-	$self->{target}->encode(@_);
+	my $target = $self->{target} || return '';
+	$target->encode(@_);
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{target};
-	$self->{target}->string;
+	my $target = $self->{target} || return '';
+	$target->string;
 }
 
 
@@ -56,7 +56,7 @@ sub target {
 	my $self = shift;
 
 	$self->{target} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{target}->name if defined wantarray && $self->{target};
+	$self->{target}->name if $self->{target};
 }
 
 
@@ -125,6 +125,6 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2672
+L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC6672
 
 =cut
