@@ -1,10 +1,10 @@
 package Net::DNS::ZoneFile;
 
 #
-# $Id: ZoneFile.pm 1360 2015-06-15 09:58:53Z willem $
+# $Id: ZoneFile.pm 1456 2016-02-17 13:34:00Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1360 $)[1];
+$VERSION = (qw$LastChangedRevision: 1456 $)[1];
 
 
 =head1 NAME
@@ -51,7 +51,7 @@ require FileHandle;
 
 use Net::DNS;
 
-use constant PERLIO => ref( eval { require PerlIO; \1; } );
+use constant PERLIO => defined eval 'require PerlIO';
 
 
 =head1 METHODS
@@ -120,6 +120,8 @@ sub read {
 
 	return &_read unless ref $self;				# compatibility interface
 
+	local $SIG{__DIE__};
+
 	if (wantarray) {
 		my @zone;					# return entire zone
 		eval {
@@ -255,6 +257,7 @@ sub _read {
 	my $zonefile = new Net::DNS::ZoneFile( _filename($filename) );
 	my @zone;
 	eval {
+		local $SIG{__DIE__};
 		my $rr;
 		push( @zone, $rr ) while $rr = $zonefile->_getRR;
 	};
@@ -270,7 +273,7 @@ sub _read {
 
 	use overload ( '<>' => 'readline' );
 
-	use constant OVERLOAD_OK => eval { no integer; $] > 5.006; };
+	use constant OVERLOAD_OK => scalar eval 'no integer; $] > 5.006';
 
 	sub new {
 		my $self = bless {}, shift;
@@ -345,7 +348,7 @@ sub parse {
 
 	use overload ( '<>' => 'readline' );
 
-	use constant OVERLOAD_OK => eval { no integer; $] > 5.006; };
+	use constant OVERLOAD_OK => scalar eval 'no integer; $] > 5.006';
 
 	sub new {
 		my $self = bless {}, shift;
